@@ -24,6 +24,7 @@ this distribution, and is available at
 U{http://www.opensource.org/licenses/bsd-license.php}
 '''
 import sys, locale, gettext, os.path, gtk.glade
+from gettext import gettext as translate_func
 
 def bind(domain, locale_dir):
   '''
@@ -61,21 +62,16 @@ DOMAIN = 'accerciser'
 # build a default instance to the LSR domain and locale directory
 _ = bind(DOMAIN, LOCALE_DIR)
 
-def Q_(s):
+def C_(ctx, s):
   '''Provide qualified translatable strings.  Some strings translate to
   more than one string in another locale.  We provide a convention to
   provide contextual information for the string so that translators can
-  do the right thing: we embed a '|' character in the string to be
-  translated.  The string before the '|' provides the context, and the
-  string after the '|' provides the string to translate.  For example:
-  'radiobutton|selected' and 'text|selected' are used to provide context
-  for the word 'selected'.
-  
-  We need to handle the case where the string has not been translated,
-  however, and we do so by stripping off the contextual information.
-
-  Plagiarized from Orca'''
-  return _(s).split('|', 1)[-1]
+  do the right thing.'''
+  translated = translate_func('%s\x04%s' % (ctx, s))
+  if '\x04' in translated:
+    # no translation found, return input string
+    return s
+  return translated
 
 # allow gettext to extract the string, but it should not be translated inline.
 N_ = lambda string: string
